==> ejc-middlemeasurement-impl-3.0.0-20220428.022448-70-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractaccountdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包月度报量台账子表
 * 
 * @author generator
 * 
 */
@TableName("ejc_middlemeasurement_subcontractaccountdetail")
public class SubcontractaccountdetailEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "mid")
	private java.lang.Long mid; // 主表id
	@TableField(value = "bill_state")
	private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	@TableField(value = "sort")
	private java.lang.String sort; // 序号
	@TableField(value = "application_no")
	private java.lang.String applicationNo; // 报量申请单编号
	@TableField(value = "contract_id")
	private java.lang.Long contractId;
	@TableField(value = "contract_name")
	private java.lang.String contractName;
	@TableField(value = "name")
	private java.lang.String name; // 分包单位名称
	@TableField(value = "reporting_time")
	private java.util.Date reportingTime; // 上报时间
	@TableField(value = "reported_quantities")
	private java.math.BigDecimal reportedQuantities; // 本月上报工程量(除税)
	@TableField(value = "tax_reported_quantities")
	private java.math.BigDecimal taxReportedQuantities; // 本月上报工程量(含税)
	@TableField(value = "cumulative_reporting")
	private java.math.BigDecimal cumulativeReporting; // 至本月累计上报工程量(除税)
	@TableField(value = "tax_cumulative_reporting")
	private java.math.BigDecimal taxCumulativeReporting; // 至本月累计上报工程量(含税)
	@TableField(value = "approval_quantity")
	private java.math.BigDecimal approvalQuantity; // 本月审批工程量(除税)
	@TableField(value = "tax_approval_quantity")
	private java.math.BigDecimal taxApprovalQuantity; // 本月审批工程量(含税)
	@TableField(value = "cumulative_approval")
	private java.math.BigDecimal cumulativeApproval; // 至本月审批工程量(除税)
	@TableField(value = "tax_cumulative_approval")
	private java.math.BigDecimal taxCumulativeApproval; // 至本月审批工程量(含税)
	@TableField(value = "payment_proportion")
	private java.math.BigDecimal paymentProportion; // 合同付款比例(%)
	@TableField(value = "cumulative_payable")
	private java.math.BigDecimal cumulativePayable; // 至本月累计应付款金额(除税)
	@TableField(value = "actual_payment")
	private java.math.BigDecimal actualPayment; // 本月实际付款金额
	@TableField(value = "cumulative_payment")
	private java.math.BigDecimal cumulativePayment; // 至本月累计付款金额
	@TableField(value = "remarks")
	private java.lang.String remarks; // 备注

	/**
	 * 主表id
	 */
	public java.lang.Long getMid() {
		return mid;
	}

	/**
	 * 主表id
	 */
	public void setMid(java.lang.Long mid) {
		this.mid = mid;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public java.lang.Integer getBillState() {
		return billState;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public void setBillState(java.lang.Integer billState) {
		this.billState = billState;
	}

	/**
	 * 序号
	 */
	public java.lang.String getSort() {
		return sort;
	}

	/**
	 * 序号
	 */
	public void setSort(java.lang.String sort) {
		this.sort = sort;
	}

	/**
	 * 报量申请单编号
	 */
	public java.lang.String getApplicationNo() {
		return applicationNo;
	}

	/**
	 * 报量申请单编号
	 */
	public void setApplicationNo(java.lang.String applicationNo) {
		this.applicationNo = applicationNo;
	}

	/**
	 * 分包单位名称
	 */
	public java.lang.String getName() {
		return name;
	}

	/**
	 * 分包单位名称
	 */
	public void setName(java.lang.String name) {
		this.name = name;
	}

	/**
	 * 上报时间
	 */
	public java.util.Date getReportingTime() {
		return reportingTime;
	}

	/**
	 * 上报时间
	 */
	public void setReportingTime(java.util.Date reportingTime) {
		this.reportingTime = reportingTime;
	}

	/**
	 * 本月上报工程量(除税)
	 */
	public java.math.BigDecimal getReportedQuantities() {
		return reportedQuantities;
	}

	/**
	 * 本月上报工程量(除税)
	 */
	public void setReportedQuantities(java.math.BigDecimal reportedQuantities) {
		this.reportedQuantities = reportedQuantities;
	}

	/**
	 * 本月上报工程量(含税)
	 */
	public java.math.BigDecimal getTaxReportedQuantities() {
		return taxReportedQuantities;
	}

	/**
	 * 本月上报工程量(含税)
	 */
	public void setTaxReportedQuantities(java.math.BigDecimal taxReportedQuantities) {
		this.taxReportedQuantities = taxReportedQuantities;
	}

	/**
	 * 至本月累计上报工程量(除税)
	 */
	public java.math.BigDecimal getCumulativeReporting() {
		return cumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(除税)
	 */
	public void setCumulativeReporting(java.math.BigDecimal cumulativeReporting) {
		this.cumulativeReporting = cumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(含税)
	 */
	public java.math.BigDecimal getTaxCumulativeReporting() {
		return taxCumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(含税)
	 */
	public void setTaxCumulativeReporting(java.math.BigDecimal taxCumulativeReporting) {
		this.taxCumulativeReporting = taxCumulativeReporting;
	}

	/**
	 * 本月审批工程量(除税)
	 */
	public java.math.BigDecimal getApprovalQuantity() {
		return approvalQuantity;
	}

	/**
	 * 本月审批工程量(除税)
	 */
	public void setApprovalQuantity(java.math.BigDecimal approvalQuantity) {
		this.approvalQuantity = approvalQuantity;
	}

	/**
	 * 本月审批工程量(含税)
	 */
	public java.math.BigDecimal getTaxApprovalQuantity() {
		return taxApprovalQuantity;
	}

	/**
	 * 本月审批工程量(含税)
	 */
	public void setTaxApprovalQuantity(java.math.BigDecimal taxApprovalQuantity) {
		this.taxApprovalQuantity = taxApprovalQuantity;
	}

	/**
	 * 至本月审批工程量(除税)
	 */
	public java.math.BigDecimal getCumulativeApproval() {
		return cumulativeApproval;
	}

	/**
	 * 至本月审批工程量(除税)
	 */
	public void setCumulativeApproval(java.math.BigDecimal cumulativeApproval) {
		this.cumulativeApproval = cumulativeApproval;
	}

	/**
	 * 至本月审批工程量(含税)
	 */
	public java.math.BigDecimal getTaxCumulativeApproval() {
		return taxCumulativeApproval;
	}

	/**
	 * 至本月审批工程量(含税)
	 */
	public void setTaxCumulativeApproval(java.math.BigDecimal taxCumulativeApproval) {
		this.taxCumulativeApproval = taxCumulativeApproval;
	}

	/**
	 * 合同付款比例(%)
	 */
	public java.math.BigDecimal getPaymentProportion() {
		return paymentProportion;
	}

	/**
	 * 合同付款比例(%)
	 */
	public void setPaymentProportion(java.math.BigDecimal paymentProportion) {
		this.paymentProportion = paymentProportion;
	}

	/**
	 * 至本月累计应付款金额(除税)
	 */
	public java.math.BigDecimal getCumulativePayable() {
		return cumulativePayable;
	}

	/**
	 * 至本月累计应付款金额(除税)
	 */
	public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
		this.cumulativePayable = cumulativePayable;
	}

	/**
	 * 本月实际付款金额
	 */
	public java.math.BigDecimal getActualPayment() {
		return actualPayment;
	}

	/**
	 * 本月实际付款金额
	 */
	public void setActualPayment(java.math.BigDecimal actualPayment) {
		this.actualPayment = actualPayment;
	}

	/**
	 * 至本月累计付款金额
	 */
	public java.math.BigDecimal getCumulativePayment() {
		return cumulativePayment;
	}

	/**
	 * 至本月累计付款金额
	 */
	public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
		this.cumulativePayment = cumulativePayment;
	}

	/**
	 * 备注
	 */
	public java.lang.String getRemarks() {
		return remarks;
	}

	/**
	 * 备注
	 */
	public void setRemarks(java.lang.String remarks) {
		this.remarks = remarks;
	}

	public java.lang.String getContractName() {
		return this.contractName;
	}

	public void setContractName(java.lang.String contractName) {
		this.contractName = contractName;
	}

	public java.lang.Long getContractId() {
		return this.contractId;
	}

	public void setContractId(java.lang.Long contractId) {
		this.contractId = contractId;
	}
}

==> ejc-middlemeasurement-impl-3.0.0-20220525.141048-104-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractaccountdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包月度报量台账子表
 * 
 * @author generator
 * 
 */
@TableName("ejc_middlemeasurement_subcontractaccountdetail")
public class SubcontractaccountdetailEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "mid")
	private java.lang.Long mid; // 主表id
	@TableField(value = "bill_state")
	private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	@TableField(value = "sort")
	private java.lang.String sort; // 序号
	@TableField(value = "application_id")
	private java.lang.String applicationId; // 报量申请单id
	@TableField(value = "application_no")
	private java.lang.String applicationNo; // 报量申请单编号
	@TableField(value = "contract_id")
	private java.lang.Long contractId;
	@TableField(value = "contract_name")
	private java.lang.String contractName;//合同名称
	@TableField(value = "name")
	private java.lang.String name; // 分包单位名称
	@TableField(value = "reporting_time")
	private java.util.Date reportingTime; // 上报时间
	@TableField(value = "reported_quantities")
	private java.math.BigDecimal reportedQuantities; // 本月上报工程量(除税)
	@TableField(value = "tax_reported_quantities")
	private java.math.BigDecimal taxReportedQuantities; // 本月上报工程量(含税)
	@TableField(value = "cumulative_reporting")
	private java.math.BigDecimal cumulativeReporting; // 至本月累计上报工程量(除税)
	@TableField(value = "tax_cumulative_reporting")
	private java.math.BigDecimal taxCumulativeReporting; // 至本月累计上报工程量(含税)
	@TableField(value = "approval_quantity")
	private java.math.BigDecimal approvalQuantity; // 本月审批工程量(除税)
	@TableField(value = "tax_approval_quantity")
	private java.math.BigDecimal taxApprovalQuantity; // 本月审批工程量(含税)
	@TableField(value = "cumulative_approval")
	private java.math.BigDecimal cumulativeApproval; // 至本月审批工程量(除税)
	@TableField(value = "tax_cumulative_approval")
	private java.math.BigDecimal taxCumulativeApproval; // 至本月审批工程量(含税)
	@TableField(value = "payment_proportion")
	private java.math.BigDecimal paymentProportion; // 合同付款比例(%)
	@TableField(value = "cumulative_payable")
	private java.math.BigDecimal cumulativePayable; // 至本月累计应付款金额(除税)
	@TableField(value = "actual_payment")
	private java.math.BigDecimal actualPayment; // 本月实际付款金额
	@TableField(value = "cumulative_payment")
	private java.math.BigDecimal cumulativePayment; // 至本月累计付款金额
	@TableField(value = "remarks")
	private java.lang.String remarks; // 备注

	/**
	 * 主表id
	 */
	public java.lang.Long getMid() {
		return mid;
	}

	/**
	 * 主表id
	 */
	public void setMid(java.lang.Long mid) {
		this.mid = mid;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public java.lang.Integer getBillState() {
		return billState;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public void setBillState(java.lang.Integer billState) {
		this.billState = billState;
	}

	/**
	 * 序号
	 */
	public java.lang.String getSort() {
		return sort;
	}

	/**
	 * 序号
	 */
	public void setSort(java.lang.String sort) {
		this.sort = sort;
	}

	public String getApplicationId() {
		return applicationId;
	}

	public void setApplicationId(String applicationId) {
		this.applicationId = applicationId;
	}

	/**
	 * 报量申请单编号
	 */
	public java.lang.String getApplicationNo() {
		return applicationNo;
	}

	/**
	 * 报量申请单编号
	 */
	public void setApplicationNo(java.lang.String applicationNo) {
		this.applicationNo = applicationNo;
	}

	/**
	 * 分包单位名称
	 */
	public java.lang.String getName() {
		return name;
	}

	/**
	 * 分包单位名称
	 */
	public void setName(java.lang.String name) {
		this.name = name;
	}

	/**
	 * 上报时间
	 */
	public java.util.Date getReportingTime() {
		return reportingTime;
	}

	/**
	 * 上报时间
	 */
	public void setReportingTime(java.util.Date reportingTime) {
		this.reportingTime = reportingTime;
	}

	/**
	 * 本月上报工程量(除税)
	 */
	public java.math.BigDecimal getReportedQuantities() {
		return reportedQuantities;
	}

	/**
	 * 本月上报工程量(除税)
	 */
	public void setReportedQuantities(java.math.BigDecimal reportedQuantities) {
		this.reportedQuantities = reportedQuantities;
	}

	/**
	 * 本月上报工程量(含税)
	 */
	public java.math.BigDecimal getTaxReportedQuantities() {
		return taxReportedQuantities;
	}

	/**
	 * 本月上报工程量(含税)
	 */
	public void setTaxReportedQuantities(java.math.BigDecimal taxReportedQuantities) {
		this.taxReportedQuantities = taxReportedQuantities;
	}

	/**
	 * 至本月累计上报工程量(除税)
	 */
	public java.math.BigDecimal getCumulativeReporting() {
		return cumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(除税)
	 */
	public void setCumulativeReporting(java.math.BigDecimal cumulativeReporting) {
		this.cumulativeReporting = cumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(含税)
	 */
	public java.math.BigDecimal getTaxCumulativeReporting() {
		return taxCumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(含税)
	 */
	public void setTaxCumulativeReporting(java.math.BigDecimal taxCumulativeReporting) {
		this.taxCumulativeReporting = taxCumulativeReporting;
	}

	/**
	 * 本月审批工程量(除税)
	 */
	public java.math.BigDecimal getApprovalQuantity() {
		return approvalQuantity;
	}

	/**
	 * 本月审批工程量(除税)
	 */
	public void setApprovalQuantity(java.math.BigDecimal approvalQuantity) {
		this.approvalQuantity = approvalQuantity;
	}

	/**
	 * 本月审批工程量(含税)
	 */
	public java.math.BigDecimal getTaxApprovalQuantity() {
		return taxApprovalQuantity;
	}

	/**
	 * 本月审批工程量(含税)
	 */
	public void setTaxApprovalQuantity(java.math.BigDecimal taxApprovalQuantity) {
		this.taxApprovalQuantity = taxApprovalQuantity;
	}

	/**
	 * 至本月审批工程量(除税)
	 */
	public java.math.BigDecimal getCumulativeApproval() {
		return cumulativeApproval;
	}

	/**
	 * 至本月审批工程量(除税)
	 */
	public void setCumulativeApproval(java.math.BigDecimal cumulativeApproval) {
		this.cumulativeApproval = cumulativeApproval;
	}

	/**
	 * 至本月审批工程量(含税)
	 */
	public java.math.BigDecimal getTaxCumulativeApproval() {
		return taxCumulativeApproval;
	}

	/**
	 * 至本月审批工程量(含税)
	 */
	public void setTaxCumulativeApproval(java.math.BigDecimal taxCumulativeApproval) {
		this.taxCumulativeApproval = taxCumulativeApproval;
	}

	/**
	 * 合同付款比例(%)
	 */
	public java.math.BigDecimal getPaymentProportion() {
		return paymentProportion;
	}

	/**
	 * 合同付款比例(%)
	 */
	public void setPaymentProportion(java.math.BigDecimal paymentProportion) {
		this.paymentProportion = paymentProportion;
	}

	/**
	 * 至本月累计应付款金额(除税)
	 */
	public java.math.BigDecimal getCumulativePayable() {
		return cumulativePayable;
	}

	/**
	 * 至本月累计应付款金额(除税)
	 */
	public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
		this.cumulativePayable = cumulativePayable;
	}

	/**
	 * 本月实际付款金额
	 */
	public java.math.BigDecimal getActualPayment() {
		return actualPayment;
	}

	/**
	 * 本月实际付款金额
	 */
	public void setActualPayment(java.math.BigDecimal actualPayment) {
		this.actualPayment = actualPayment;
	}

	/**
	 * 至本月累计付款金额
	 */
	public java.math.BigDecimal getCumulativePayment() {
		return cumulativePayment;
	}

	/**
	 * 至本月累计付款金额
	 */
	public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
		this.cumulativePayment = cumulativePayment;
	}

	/**
	 * 备注
	 */
	public java.lang.String getRemarks() {
		return remarks;
	}

	/**
	 * 备注
	 */
	public void setRemarks(java.lang.String remarks) {
		this.remarks = remarks;
	}

	public java.lang.String getContractName() {
		return this.contractName;
	}

	public void setContractName(java.lang.String contractName) {
		this.contractName = contractName;
	}

	public java.lang.Long getContractId() {
		return this.contractId;
	}

	public void setContractId(java.lang.Long contractId) {
		this.contractId = contractId;
	}
}
